/**
 * JASMINe
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id:$
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.monitoring.eventswitch.endpoints;

import java.io.IOException;
import java.util.logging.Level;
import java.util.logging.Logger;

import javax.naming.NamingException;

import org.ow2.jasmine.monitoring.eventswitch.beans.JasmineEventEB;
import org.ow2.jasmine.monitoring.eventswitch.beans.JasmineEventSLBRemote;
import org.ow2.jasmine.monitoring.eventswitch.messages.JasmineEvent;
import org.ow2.jasmine.monitoring.eventswitch.messages.JasmineEventDetails;

/**
 * A wrapper class that accesses JasmineEvent objects via EJB3.
 */
public class JasmineEventEJB3Wrapper extends MuleEJB3Wrapper<JasmineEventSLBRemote> {
    /**
     * Starts the {@link MuleEJB3Wrapper} in deferred mode.
     */
    public JasmineEventEJB3Wrapper() {
        super(true);
    }

    /**
     * Saves each event detail in a JASMINe Event.
     *
     * @param e JasmineEvent to save.
     *
     * @throws NamingException On naming failure.
     * @throws IOException On configuration file failure.
     */
    public void saveJasmineEvent(final JasmineEvent e) {
        try {
            for (JasmineEventDetails d : e.getEvents()) {

                getBean().saveEvent(
                    new JasmineEventEB(e.getDomain(), e.getServer(), d.getSource(), d.getProbe(), d.getValue(), d.getTimestamp(),
                            d.getSname()));

            }
        } catch (NamingException e1) {
            Logger.getLogger(JasmineEventEJB3Wrapper.class.getName()).log(Level.WARNING,"EJBs are not ready ... the message is not persisted");
        } catch (IOException e1) {
            Logger.getLogger(JasmineEventEJB3Wrapper.class.getName()).log(Level.WARNING,"EJBs are not ready ... the message is not persisted");
        }
    }
}
