/**
 * JASMINe
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id:$
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.monitoring.eventswitch.transformers;

import java.text.SimpleDateFormat;

import org.mule.transformers.AbstractTransformer;
import org.ow2.jasmine.monitoring.eventswitch.messages.JasmineEvent;
import org.ow2.jasmine.monitoring.eventswitch.messages.JasmineEventDetails;

/**
 * Transforms a JASMINe event into a (very cluttering) string.
 */
public class JasmineEventToString extends AbstractTransformer {
    /**
     * Registers the transformer on Mule.
     *
     * @see org.mule.transformers.AbstractTransformer
     */
    public JasmineEventToString() {
        super();
        this.registerSourceType(JasmineEvent.class);
        this.setReturnClass(String.class);
    }

    /**
     * Transforms a JASMINe event into a (very cluttering) string.
     *
     * @param src      @see org.mule.transformers.AbstractTransformer.doTransform
     * @param encoding @see org.mule.transformers.AbstractTransformer.doTransform
     *
     * @return src transformed into a (very cluttering) string.
     */
    public Object doTransform(final Object src, final String encoding) {
        JasmineEvent event = (JasmineEvent) src;
        String result = "JASMINe Event object for "+event.getDomain()+"."+event.getServer()
                      + " has "+event.getEvents().size()+" events:";
        for(JasmineEventDetails ed : event.getEvents()) {
            result += "\n\tProbe:  "+ed.getProbe()
                    + "\n\tTime:   "+(new SimpleDateFormat("MM/dd/yyyy, HH:mm:ss z").format(ed.getTimestamp()))
                    + "\n\tValue:  "+ed.getValue()
                    + "\n\t\t-----";
        }
        return result;
    }
}
